==> python-dnsimple-5.0.0-1-any.pkg.tar.zst: usr/lib/python3.13/site-packages/dnsimple/struct/__init__.py <==
from dnsimple.struct.struct import Struct
from dnsimple.struct.access_token import AccessToken
from dnsimple.struct.account import Account
from dnsimple.struct.certificate import Certificate, CertificateBundle, LetsencryptCertificateInput, LetsencryptCertificateRenewalInput, CertificatePurchase, CertificateRenewal
from dnsimple.struct.charge import Charge, ChargeItem
from dnsimple.struct.collaborator import Collaborator
from dnsimple.struct.contact import Contact
from dnsimple.struct.dnssec import Dnssec
from dnsimple.struct.delegation_signer_record import DelegationSignerRecord, DelegationSignerRecordInput
from dnsimple.struct.domain import Domain
from dnsimple.struct.domain_check import DomainCheck
from dnsimple.struct.domain_premium_price import DomainPremiumPrice, DomainPremiumPriceOptions
from dnsimple.struct.domain_price import DomainPrice
from dnsimple.struct.domain_registration import DomainRegistration, DomainRegistrationRequest
from dnsimple.struct.domain_renewal import DomainRenewal, DomainRenewRequest
from dnsimple.struct.domain_restore import DomainRestore, DomainRestoreRequest
from dnsimple.struct.domain_transfer import DomainTransfer, DomainTransferRequest
from dnsimple.struct.domain_transfer_lock import DomainTransferLock
from dnsimple.struct.domain_push import DomainPush
from dnsimple.struct.dns_analytics import DnsAnalytics
from dnsimple.struct.email_forward import EmailForward, EmailForwardInput
from dnsimple.struct.registrant import RegistrantChange, CheckRegistrantChangeInput, CreateRegistrantChangeInput, RegistrantChangeCheck
from dnsimple.struct.service import Service
from dnsimple.struct.template import Template
from dnsimple.struct.template_record import TemplateRecord
from dnsimple.struct.tld import Tld, TldExtendedAttribute, TldExtendedAttributeOption
from dnsimple.struct.user import User
from dnsimple.struct.vanity_name_server import VanityNameServer
from dnsimple.struct.webhook import Webhook
from dnsimple.struct.whoami import Whoami
from dnsimple.struct.whois_privacy import WhoisPrivacy, WhoisPrivacyRenewal
from dnsimple.struct.zone import Zone
from dnsimple.struct.zone_distribution import ZoneDistribution
from dnsimple.struct.zone_file import ZoneFile
from dnsimple.struct.zone_record import ZoneRecord, ZoneRecordInput, ZoneRecordUpdateInput

==> python-dnsimple-6.1.0-2-any.pkg.tar.zst: usr/lib/python3.14/site-packages/dnsimple/struct/__init__.py <==
from dnsimple.struct.struct import Struct
from dnsimple.struct.access_token import AccessToken
from dnsimple.struct.account import Account
from dnsimple.struct.certificate import Certificate, CertificateBundle, LetsencryptCertificateInput, LetsencryptCertificateRenewalInput, CertificatePurchase, CertificateRenewal
from dnsimple.struct.charge import Charge, ChargeItem
from dnsimple.struct.collaborator import Collaborator
from dnsimple.struct.contact import Contact
from dnsimple.struct.dnssec import Dnssec
from dnsimple.struct.delegation_signer_record import DelegationSignerRecord, DelegationSignerRecordInput
from dnsimple.struct.domain import Domain
from dnsimple.struct.domain_check import DomainCheck
from dnsimple.struct.domain_premium_price import DomainPremiumPrice, DomainPremiumPriceOptions
from dnsimple.struct.domain_price import DomainPrice
from dnsimple.struct.domain_registration import DomainRegistration, DomainRegistrationRequest
from dnsimple.struct.domain_renewal import DomainRenewal, DomainRenewRequest
from dnsimple.struct.domain_restore import DomainRestore, DomainRestoreRequest
from dnsimple.struct.domain_transfer import DomainTransfer, DomainTransferRequest
from dnsimple.struct.domain_transfer_lock import DomainTransferLock
from dnsimple.struct.domain_push import DomainPush
from dnsimple.struct.dns_analytics import DnsAnalytics
from dnsimple.struct.email_forward import EmailForward, EmailForwardInput
from dnsimple.struct.registrant import RegistrantChange, CheckRegistrantChangeInput, CreateRegistrantChangeInput, RegistrantChangeCheck
from dnsimple.struct.service import Service
from dnsimple.struct.template import Template
from dnsimple.struct.template_record import TemplateRecord
from dnsimple.struct.tld import Tld, TldExtendedAttribute, TldExtendedAttributeOption
from dnsimple.struct.user import User
from dnsimple.struct.vanity_name_server import VanityNameServer
from dnsimple.struct.webhook import Webhook
from dnsimple.struct.whoami import Whoami
from dnsimple.struct.whois_privacy import WhoisPrivacy, WhoisPrivacyRenewal
from dnsimple.struct.zone import Zone
from dnsimple.struct.zone_distribution import ZoneDistribution
from dnsimple.struct.zone_file import ZoneFile
from dnsimple.struct.zone_record import ZoneRecord, ZoneRecordInput, ZoneRecordUpdateInput
from dnsimple.struct.batch_change_zone_records import (
    BatchChangeZoneRecordsInput,
    BatchChangeZoneRecordsCreateInput,
    BatchChangeZoneRecordsUpdateInput,
    BatchChangeZoneRecordsDeleteInput,
    BatchChangeZoneRecordsResponse,
    BatchChangeZoneRecordsDeleteResponse
)
